Learn R Programming

msarc (version 1.4.3)

msarc.tagCloud: Draw Tag Cloud

Description

Given an msarc object, draw the corresponding tag cloud.

Usage

msarc.tagCloud(msarc, pal=NA,...)

Arguments

msarc
an msarc object to draw.
pal
an RColorBrewer palette to use for word colours. Default is brewer.pal(10,"Spectral").
...
additional arguments passed to wordcloud.

Value

  • Does not return a value.

Details

The main purpose of this function is to draw a tag cloud (word cloud) of the identified proteins, with size indicating Mascot score.

The tag cloud will be drawn on the current device; it is the user's responsibility to open a connection to a file, or other device as applicable.

Examples

Run this code
data('sample_complete',package="msarc")
msarc.tagCloud(sample_complete)

Run the code above in your browser using DataLab