powered by
msarc
msarc.tagCloud(msarc, pal=NA,...)
brewer.pal(10,"Spectral")
wordcloud
The tag cloud will be drawn on the current device; it is the user's responsibility to open a connection to a file, or other device as applicable.
data('sample_complete',package="msarc") msarc.tagCloud(sample_complete)
Run the code above in your browser using DataLab